@@ -314,9 +314,6 @@ class Auth(object):
             must_update_hash = (hash_alg != self.settings.hash_alg)
             must_update_cost = (hash_cost != self.settings.hash_cost)
             if must_update_hash or must_update_cost:
-                print '\n------------ Must update! -------------\n'
-                print hash_alg, self.settings.hash_alg
-                print hash_cost, self.settings.hash_cost
                 user.password = self.hash_password(password)
         return user
 
