@@ -51,7 +51,7 @@ def get_user_model():
     return User
 
 
-def get_auth(hash_alg='sha512', hash_cost=10):
+def get_auth(hash_alg='dsha512', hash_cost=10):
     User = get_user_model()
     settings = auth_settings.copy()
     settings['hash_alg'] = hash_alg
@@ -141,7 +141,7 @@ def test_authenticate_and_update():
     User = get_user_model()
 
     settings = auth_settings.copy()
-    settings['hash_alg'] = 'sha512'
+    settings['hash_alg'] = 'dsha512'
     settings['hash_cost'] = 10
     settings['pepper'] = 'dc47d3062962d5b9f5828dccc47b9d7eda95ecf6'
     auth = shake_auth.Auth(User, **settings)
